@@ -58,6 +58,8 @@ class SemanageCoreTranslationProcess;
 class SemanageCoreBooleanProcess;
 class AutoRelabel;
 class Policygeneration;
+class Aureport;
+class Ausearch;
 
 class MainWindow : public QMainWindow
 {
@@ -114,6 +116,8 @@ private slots:
     void semanage_core_boolean_process();
     void autorelabel_process();
     void policygeneration_process();
+    void aureport();
+    void ausearch();
 
     void save();
     void saveAs();
@@ -184,6 +188,8 @@ private:
     SemanageCoreBooleanProcess *semanage_core_boolean_process_o;
     AutoRelabel *autorelabel_process_o;
     Policygeneration *policygeneration_process_o;
+    Aureport *aureport_o;
+    Ausearch *ausearch_o;
     
     QPopupMenu *fileMenu;
     QPopupMenu *editMenu;
@@ -193,6 +199,7 @@ private:
     QPopupMenu *parselinesMenu;
     QPopupMenu *selpawMenu;
     QPopupMenu *refineMenu;
+    QPopupMenu *auditMenu;
     QPopupMenu *policyMenu;
     QPopupMenu *manageMenu;
     QPopupMenu *semanageMenu;
@@ -257,6 +264,8 @@ private:
     QAction *semanage_core_boolean_processAct;
     QAction *autorelabel_processAct;
     QAction *policygeneration_processAct;
+    QAction *aureportAct;
+    QAction *ausearchAct;
 };
 
 #endif
