@@ -121,27 +121,27 @@
     </message>
     <message>
         <source>Search about</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">次の項目を検索</translation>
     </message>
     <message>
         <source>close</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">閉じる</translation>
     </message>
     <message>
         <source>events (audit-event-id)</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">イベント（オーディットイベントid）</translation>
     </message>
     <message>
         <source>come name (comm-name)</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">コマンド名（コマンド名）</translation>
     </message>
     <message>
         <source>filename (file-name)</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">ファイル名(ファイル名)</translation>
     </message>
     <message>
         <source>group ID (all-group-id)</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">グループid(全てのグループid)</translation>
     </message>
     <message>
         <source>effective group ID (effective-group-id)</source>
@@ -149,15 +149,15 @@
     </message>
     <message>
         <source>group ID (group-id)</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">グループid（グループid）</translation>
     </message>
     <message>
         <source>help</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">ヘルプ</translation>
     </message>
     <message>
         <source>host name (host-name)</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">ホスト名（ホスト名）</translation>
     </message>
     <message>
         <source>key string (key-string)</source>
@@ -165,11 +165,31 @@
     </message>
     <message>
         <source>node (node-name)</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">ノード（ノード名）</translation>
     </message>
     <message>
         <source>Search</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">検索</translation>
+    </message>
+    <message>
+        <source>object (SE-Linux-context-string)</source>
+        <translation type="unfinished">オブジェクト（SELinuxに関連する文字列）</translation>
+    </message>
+    <message>
+        <source>input (file-name)</source>
+        <translation type="unfinished">次のファイルから読み込む（ファイル名）</translation>
+    </message>
+    <message>
+        <source>pid (process-id)</source>
+        <translation type="unfinished">プロセスid（プロセスid）</translation>
+    </message>
+    <message>
+        <source>syscall (syscall-name-or-value)</source>
+        <translation type="unfinished">システムコール（システムコール名又は値）</translation>
+    </message>
+    <message>
+        <source>Interpret numeric entities into text</source>
+        <translation type="unfinished">数字要素を文字列に変換</translation>
     </message>
 </context>
 <context>
@@ -274,7 +294,7 @@ Do you want to save your changes?</source>
     <name>MainWindow</name>
     <message>
         <source>segatex-5.40</source>
-        <translation type="unfinished">segatexバージョン5.40</translation>
+        <translation type="obsolete">segatexバージョン5.40</translation>
     </message>
     <message>
         <source>&amp;New</source>
@@ -862,7 +882,7 @@ Do you want to save your changes?</source>
     </message>
     <message>
         <source>&lt;h2&gt;segatex-5.40&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatex is a SELinux tool&lt;p&gt;&lt;b&gt;written with Qt&lt;/b&gt;.</source>
-        <translation type="unfinished">&lt;h2&gt;segatex-5.40&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatexはSELinuxのツールです。&lt;p&gt;&lt;b&gt;Qtを使用して書かれています。&lt;/b&gt;.</translation>
+        <translation type="obsolete">&lt;h2&gt;segatex-5.40&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatexはSELinuxのツールです。&lt;p&gt;&lt;b&gt;Qtを使用して書かれています。&lt;/b&gt;.</translation>
     </message>
     <message>
         <source>&amp;Ausearch</source>
@@ -872,6 +892,14 @@ Do you want to save your changes?</source>
         <source>Ausearch</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>segatex-5.50</source>
+        <translation type="unfinished">segatexバージョン5.50</translation>
+    </message>
+    <message>
+        <source>&lt;h2&gt;segatex-5.50&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatex is a SELinux tool&lt;p&gt;&lt;b&gt;written with Qt&lt;/b&gt;.</source>
+        <translation type="unfinished">&lt;h2&gt;segatex-5.50&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatexはSELinuxのツールです。&lt;p&gt;&lt;b&gt;Qtを使用して書かれています。&lt;/b&gt;.</translation>
+    </message>
 </context>
 <context>
     <name>Policygeneration</name>
@@ -1131,6 +1159,30 @@ Do you want to save your changes?</source>
         <source>permissive</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>SELinux default policy is targeted and should be started in enforcing !</source>
+        <translation type="obsolete">SELinuxのデフォルトポリシは限定で、強制モードで立ち上がります！</translation>
+    </message>
+    <message>
+        <source>SELinux default policy is targeted and should be started in permissive !</source>
+        <translation type="obsolete">SELinuxのデフォルトポリシは限定で、ログモードで立ち上がります！</translation>
+    </message>
+    <message>
+        <source>SELinux default policy is strict and should be started in enforcing !</source>
+        <translation type="obsolete">SELinuxのデフォルトポリシは厳密で、強制モードで立ち上がります！</translation>
+    </message>
+    <message>
+        <source>SELinux default policy is strict and should be started in permissive !</source>
+        <translation type="obsolete">SELinuxのデフォルトポリシは厳密で、ログモードで立ち上がります！</translation>
+    </message>
+    <message>
+        <source>SELinux default policy is mls and should be started in enforcing !</source>
+        <translation type="obsolete">SELinuxのデフォルトポリシはマルチレベルで、強制モードで立ち上がります！</translation>
+    </message>
+    <message>
+        <source>SELinux default policy is mls and should be started in permissive !</source>
+        <translation type="obsolete">SELinuxのデフォルトポリシはマルチレベルで、ログモードで立ち上がります！</translation>
+    </message>
 </context>
 <context>
     <name>SegatexYum</name>
